cli

package
v0.7.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 21, 2025 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewWatermarkCommand

func NewWatermarkCommand(container *services.ServiceContainer) *cobra.Command

NewWatermarkCommand creates the watermark command and subcommands

Types

This section is empty.

Directories

Path Synopsis
Package commands provides all CLI command implementations for Shadowforge
Package commands provides all CLI command implementations for Shadowforge
Package root provides the root command and command tree for the Shadowforge CLI
Package root provides the root command and command tree for the Shadowforge CLI
Package services provides service initialization and dependency injection for the CLI
Package services provides service initialization and dependency injection for the CLI

Jump to